==> HostCMS-6.1.7.tar: modules/affiliate/plan/i18n/en.php <==
<?php
/**
 * Affiliates.
 *
 * @package HostCMS 6\Affiliate
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2012 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'affiliate_title' => 'Affiliate program',
	'model_name' => 'Affiliate program',
	'affiliate_menu_title' => 'Affiliate program',
	'affiliate_menu_title_add' => 'Add',
	'affiliate_form_add' => 'Add affiliate program',
	'affiliate_form_edit' => 'Edit affiliate program',
	'name' => '<acronym title="Name of affiliate program">Name</acronym>',
	'description' => '<acronym title="Description of affiliate program">Description</acronym>',
	'site_id' => '<acronym title="Website on which affiliate program is accessible">Website</acronym>',
	'active' => '<acronym title="Activity checkbox of affiliate program">Activity</acronym>',
	'siteuser_group_id' => '<acronym title="Website user group that has access rights to affiliate program">Website user group</acronym>',
	'datetime' => '<acronym title="Last modified date of affiliate program">Last modified date</acronym>',
	'min_count_of_items' => '<acronym title="Minimum products amount that user should buy at a time to receive affiliate program charge">Minimum products amount</acronym>',
	'min_amount_of_items' => '<acronym title="Minimum amount in currency of online store that user should buy at a time to receive affiliate program charge">Minimum amount in currency of online store</acronym>',
	'include_delivery' => '<acronym title="Include product delivery when calculating affiliate\'s commission?">Product delivery</acronym>',
	'id' => 'Id',
	'edit_success' => 'Affiliate program information modified successfully',
	'edit_error' => 'Error while adding affiliate program information',
	'markDeleted_success' => 'Affiliate program information deleted successfully',
	'affiliate_assotiation_form_title' => 'Affiliate programs accessible to online store "%s"',
	'changeStatus_success' => "Information has been successfully changed",
	'changeStatusOn_success' => "Information has been successfully changed",
	'changeStatusOff_success' => "Information has been successfully changed",
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
);

==> HostCMS-6.8.6.tar: modules/affiliate/plan/i18n/en.php <==
<?php
/**
 * Affiliates.
 *
 * @package HostCMS
 * @subpackage Affiliate
 * @version 6.x
 * @author Hostmake LLC
 * @copyright © 2005-2018 ООО "Хостмэйк" (Hostmake LLC), http://www.hostcms.ru
 */
return array(
	'affiliate_title' => 'Affiliate program',
	'model_name' => 'Affiliate program',
	'affiliate_menu_title' => 'Affiliate program',
	'affiliate_menu_title_add' => 'Add',
	'affiliate_form_add' => 'Add affiliate program',
	'affiliate_form_edit' => 'Edit affiliate program',
	'name' => 'Name',
	'description' => 'Description',
	'site_id' => '<acronym title="Website on which affiliate program is accessible">Website</acronym>',
	'active' => 'Active',
	'siteuser_group_id' => '<acronym title="Website user group that has access rights to affiliate program">Website user group</acronym>',
	'datetime' => '<acronym title="Last modified date of affiliate program">Last modified date</acronym>',
	'min_count_of_items' => '<acronym title="Minimum products amount that user should buy at a time to receive affiliate program charge">Minimum products amount</acronym>',
	'min_amount_of_items' => '<acronym title="Minimum amount in currency of online store that user should buy at a time to receive affiliate program charge">Minimum amount in currency of online store</acronym>',
	'include_delivery' => '<acronym title="Include product delivery when calculating affiliate\'s commission?">Product delivery</acronym>',
	'id' => 'ID',
	'edit_success' => 'Affiliate program information modified successfully',
	'edit_error' => 'Error while adding affiliate program information',
	'markDeleted_success' => 'Affiliate program information deleted successfully',
	'affiliate_assotiation_form_title' => 'Affiliate programs accessible to online store "%s"',
	'changeStatus_success' => "Information has been successfully changed",
	'changeStatusOn_success' => "Information has been successfully changed",
	'changeStatusOff_success' => "Information has been successfully changed",
	'delete_success' => 'Item deleted successfully!',
	'undelete_success' => 'Item restored successfully!',
);
